"""
This module has the code to infer PSF models.

Interface:
    classes should be parametrized by, at least, flux and
    centroid positions, which should be of type tf.Variable.
"""

import numpy as np
import tensorflow as tf

class Gaussian:
    """
    shape : tuple
        shape of the TPF. (row_shape, col_shape)
    col_ref, row_ref : int, int
        column and row coordinates of the bottom
        left corner of the TPF
    """
    def __init__(self, shape, col_ref, row_ref):
        self.shape = shape
        self.col_ref = col_ref
        self.row_ref = row_ref
        self._init_grid()

    def _init_grid(self):
        r, c = self.row_ref, self.col_ref
        s1, s2 = self.shape
        self.y, self.x = np.mgrid[r:r+s1-1:1j*s1, c:c+s2-1:1j*s2]

    def __call__(self, *params):
        return self.evaluate(*params)

    def evaluate(self, flux, xo, yo, a, b, c):
        psf = tf.exp(-(a * (self.x - xo) ** 2
                       + 2 * b * (self.x - xo) * (self.y - yo)
                       + c * (self.y - yo) ** 2))
        psf_sum = tf.reduce_sum(psf)
        return flux * psf / psf_sum



"""This module implements the necessary code
to perform PSF photometry.
"""

import tqdm

class PSFPhotometry:
    def __init__(self, optimizer):
        self.optimizer = optimizer

    def fit(self, pixel_flux, data_placeholder, var_list, session):
        opt_params = []
        cadences = range(pixel_flux.shape[0])

        for n in tqdm.tqdm(cadences):
            self.optimizer.minimize(session=session, feed_dict={data_placeholder: pixel_flux[n]})
            opt_params.append([session.run(var) for var in var_list])

        return np.asarray(opt_params)



#!/usr/bin/env python
import sys
from setuptools import setup
# To use a consistent encoding
from codecs import open
import os
from os import path

# Prepare and send a new release to PyPI
if "release" in sys.argv[-1]:
    os.system("python setup.py sdist")
    os.system("twine upload dist/*")
    os.system("rm -rf dist/vaneska*")
    sys.exit()

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='vaneska',
    packages=['vaneska'],
    version='0.0dev',
    description='Sweet PSF photometry tool for TESS',
    long_description=long_description,
    url='https://github.com/mirca/vaneska',
    author='mirca',
    author_email='jvmirca@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
    ],
    tests_require=['pytest', 'pytest-cov'],
    keywords='statistics probability',
    install_requires=['numpy', ['tensorflow']]
)
